.. _sec_install:

Installation
============

.. automodule:: gunpowder
   :noindex:

For the latest version:

.. code-block:: bash

   pip install git+https://github.com/janelia-cellmap/dacapo

Optional(Web GUI):

For the latest version:

.. code-block:: bash

   pip install git+https://github.com/funkelab/dacapo-dashboard